@@ -1,12 +1,16 @@
 package SDL::GFX::ImageFilter;
 use strict;
 use warnings;
-use vars qw(@ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants ':SDL::GFX';
 our @ISA = qw(Exporter DynaLoader);
 
+our $VERSION    = '2.541_09';
+our $XS_VERSION = $VERSION;
+$VERSION = eval $VERSION;
+
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
