@@ -1,19 +1,26 @@
 package SDL::Mixer::Groups;
 use strict;
 use warnings;
-use vars qw(@ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants qw(:SDL::Mixer :SDL::Audio);
 our @ISA = qw(Exporter DynaLoader);
 
+our $VERSION    = '2.541_09';
+our $XS_VERSION = $VERSION;
+$VERSION = eval $VERSION;
+
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
 bootstrap SDL::Mixer::Groups;
 
 use base 'Exporter';
-our @EXPORT      = (@{ $SDL::Constants::EXPORT_TAGS{'SDL::Mixer'} }, @{ $SDL::Constants::EXPORT_TAGS{'SDL::Audio'} });
+our @EXPORT = (
+	@{ $SDL::Constants::EXPORT_TAGS{'SDL::Mixer'} },
+	@{ $SDL::Constants::EXPORT_TAGS{'SDL::Audio'} }
+);
 our %EXPORT_TAGS = (
 	all      => \@EXPORT,
 	init     => $SDL::Constants::EXPORT_TAGS{'SDL::Mixer/init'},
@@ -24,4 +31,4 @@ our %EXPORT_TAGS = (
 	status   => $SDL::Constants::EXPORT_TAGS{'SDL::Audio/status'}
 );
 
-1;
\ No newline at end of file
+1;
