@@ -4,6 +4,9 @@
 
 #include <SDL.h>
 #include "SDL_thread.h"
+#ifndef Uint32
+#define Uint32 uint32_t
+#endif
 
 PerlInterpreter * perl = NULL;
 
@@ -13,7 +16,7 @@ void *bag2obj( SV *bag )
 
     if( sv_isobject(bag) && (SvTYPE(SvRV(bag)) == SVt_PVMG) )
     {
-        void **pointers = (void **)(SvIV((SV *)SvRV( bag ))); 
+        void **pointers = (void **)INT2PTR(void *, SvIV((SV *)SvRV( bag ))); 
         obj             = (void *)(pointers[0]);
     }
     
@@ -22,11 +25,15 @@ void *bag2obj( SV *bag )
 
 SV *obj2bag( int size_ptr,  void *obj, char *CLASS )
 {
-    SV *   objref    = newSV( size_ptr );
-    void** pointers  = safemalloc(3 * sizeof(void*));
+    SV *   objref;
+    void** pointers;
+    Uint32 *threadid;
+
+    objref    = newSV( size_ptr );
+    pointers  = safemalloc(3 * sizeof(void*));
     pointers[0]      = (void*)obj;
     pointers[1]      = (void*)PERL_GET_CONTEXT;
-    Uint32 *threadid = (Uint32 *)safemalloc(sizeof(Uint32));
+    threadid = (Uint32 *)safemalloc(sizeof(Uint32));
     *threadid        = SDL_ThreadID();
     pointers[2]      = (void*)threadid;
     sv_setref_pv( objref, CLASS, (void *)pointers);
@@ -35,17 +42,23 @@ SV *obj2bag( int size_ptr,  void *obj, char *CLASS )
 
 SV *cpy2bag( void *object, int p_size, int s_size, char *package )
 {
-    SV   *ref  = newSV( p_size );
-    void *copy = safemalloc( s_size );
+    void** pointers;
+    Uint32 *threadid;
+    SV* ref;
+    SV* a;
+    void *copy;
+    
+    ref  = newSV( p_size );
+    copy = safemalloc( s_size );
     memcpy( copy, object, s_size );
 
-    void** pointers  = safemalloc(3 * sizeof(void*));
+    pointers  = safemalloc(3 * sizeof(void*));
     pointers[0]      = (void*)copy;
     pointers[1]      = (void*)PERL_GET_CONTEXT;
-    Uint32 *threadid = (Uint32 *)safemalloc(sizeof(Uint32));
+    threadid = (Uint32 *)safemalloc(sizeof(Uint32));
     *threadid        = SDL_ThreadID();
     pointers[2]      = (void*)threadid;
-    SV* a            = sv_setref_pv(ref, package, (void *)pointers);
+    a            = sv_setref_pv(ref, package, (void *)pointers);
     return a;
 }
 
@@ -53,7 +66,7 @@ void objDESTROY(SV *bag, void (* callback)(void *object))
 {
     if( sv_isobject(bag) && (SvTYPE(SvRV(bag)) == SVt_PVMG) )
     {
-        void** pointers  = (void**)(SvIV((SV*)SvRV( bag )));
+        void** pointers  = (void**)INT2PTR(void *, SvIV((SV *)SvRV( bag )));
         void* object     = pointers[0];
         Uint32 *threadid = (Uint32*)(pointers[2]);
         
@@ -71,16 +84,20 @@ void objDESTROY(SV *bag, void (* callback)(void *object))
 
 SV *_sv_ref( void *object, int p_size, int s_size, char *package )
 {
-    SV   *ref  = newSV( p_size );
-    void *copy = safemalloc( s_size );
-    memcpy( copy, object, s_size );
+    SV   *ref;
+    void *copy;
+    void** pointers;
+    Uint32 *threadid;
 
-    void** pointers  = safemalloc(3 * sizeof(void*));
-    pointers[0]      = (void*)copy;
-    pointers[1]      = (void*)perl;
-    Uint32 *threadid = (Uint32 *)safemalloc(sizeof(Uint32));
-    *threadid        = SDL_ThreadID();
-    pointers[2]      = (void*)threadid;
+    ref         = newSV( p_size );
+    copy        = safemalloc( s_size );
+    memcpy( copy, object, s_size );
+    pointers    = safemalloc(3 * sizeof(void*));
+    pointers[0] = (void*)copy;
+    pointers[1] = (void*)perl;
+    threadid    = (Uint32 *)safemalloc(sizeof(Uint32));
+    *threadid   = SDL_ThreadID();
+    pointers[2] = (void*)threadid;
 
     return sv_setref_pv(ref, package, (void *)pointers);
 }
